pub fn validate_font_asset(path: &Path) -> Result<FontIdentity, RenderError>Expand description
Validate an explicitly supplied font against the same frozen identity.
pub fn validate_font_asset(path: &Path) -> Result<FontIdentity, RenderError>Validate an explicitly supplied font against the same frozen identity.